==> claromentis-framework-9.6.6-26891208.zip: web/intranet/infocapture/classes/Event/TrafficLightEditEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
class TrafficLightEditEvent extends Event
{
    
    
    
    
    protected $project_id;
    
    
    
    
    protected $sla_id;
    
    
    
    
    protected $sla_name;
    
    
    
    
    protected $sla_old_name;
    
    
    
    
    protected $sla_color;
    
    
    
    
    protected $sla_old_color;
    public function __construct(int $project_id, int $_b28326255a97ea4fb3e0c1f3587e7d40, string $_c2c38a8e22e5302226323531c9851adb, ?string $_b3b5fd8c8d166b50a295b7cd720b4748, string $_fe150388a43d11c5d553146eeba7d9c3, ?string $_ec81392d67a83ac740f8dcb2399595ba)
    {
        $this->project_id = $project_id;
        $this->sla_id = $_b28326255a97ea4fb3e0c1f3587e7d40;
        $this->sla_name = $_c2c38a8e22e5302226323531c9851adb;
        $this->sla_old_name = $_b3b5fd8c8d166b50a295b7cd720b4748;
        $this->sla_color = $_fe150388a43d11c5d553146eeba7d9c3;
        $this->sla_old_color = $_ec81392d67a83ac740f8dcb2399595ba;
    }
    
    
    
    
    public function getProjectId() : int
    {
        return $this->project_id;
    }
    
    
    
    
    public function getSlaName() : string
    {
        return $this->sla_name;
    }
    
    
    
    
    public function getSlaId() : int
    {
        return $this->sla_id;
    }
    
    
    
    
    public function getSlaColor() : string
    {
        return $this->sla_color;
    }
    
    
    
    
    public function getSlaOldColor() : ?string
    {
        return $this->sla_old_color;
    }
    
    
    
    
    public function getSlaOldName() : ?string
    {
        return $this->sla_old_name;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/infocapture/classes/Event/TrafficLightEditEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
class TrafficLightEditEvent extends Event
{
    
    
    
    
    protected $project_id;
    
    
    
    
    protected $sla_id;
    
    
    
    
    protected $sla_name;
    
    
    
    
    protected $sla_old_name;
    
    
    
    
    protected $sla_color;
    
    
    
    
    protected $sla_old_color;
    public function __construct(int $project_id, int $_b28326255a97ea4fb3e0c1f3587e7d40, string $_c2c38a8e22e5302226323531c9851adb, ?string $_b3b5fd8c8d166b50a295b7cd720b4748, string $_fe150388a43d11c5d553146eeba7d9c3, ?string $_ec81392d67a83ac740f8dcb2399595ba)
    {
        $this->project_id = $project_id;
        $this->sla_id = $_b28326255a97ea4fb3e0c1f3587e7d40;
        $this->sla_name = $_c2c38a8e22e5302226323531c9851adb;
        $this->sla_old_name = $_b3b5fd8c8d166b50a295b7cd720b4748;
        $this->sla_color = $_fe150388a43d11c5d553146eeba7d9c3;
        $this->sla_old_color = $_ec81392d67a83ac740f8dcb2399595ba;
    }
    
    
    
    
    public function getProjectId() : int
    {
        return $this->project_id;
    }
    
    
    
    
    public function getSlaName() : string
    {
        return $this->sla_name;
    }
    
    
    
    
    public function getSlaId() : int
    {
        return $this->sla_id;
    }
    
    
    
    
    public function getSlaColor() : string
    {
        return $this->sla_color;
    }
    
    
    
    
    public function getSlaOldColor() : ?string
    {
        return $this->sla_old_color;
    }
    
    
    
    
    public function getSlaOldName() : ?string
    {
        return $this->sla_old_name;
    }
}
